@@ -15,8 +15,7 @@
 # GNU General Public License for more details.
 #
 # You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+# along with this program; if not, see <http://www.gnu.org/licenses/>.
 
 # Parts from "Interactive Python-GTK Console" (stolen from epiphany's
 # console.py)
@@ -35,7 +34,7 @@
 
 from console import PythonConsole
 
-__all__ = ('PythonConsole', 'OutFile')
+__all__ = ('PythonConsole', 'OutFile') # pylint: disable-msg=E0603
 
 from gi.repository import GObject, Peas, Gtk, Totem # pylint: disable-msg=E0611
 from gi.repository import Gio # pylint: disable-msg=E0611
@@ -52,19 +51,6 @@ gettext.textdomain ("totem")
 D_ = gettext.dgettext
 _ = gettext.gettext
 
-UI_STR = """
-<ui>
-  <menubar name="tmw-menubar">
-    <menu name="Python" action="Python">
-      <placeholder name="ToolsOps_5">
-        <menuitem name="PythonConsole" action="PythonConsole"/>
-        <menuitem name="PythonDebugger" action="PythonDebugger"/>
-      </placeholder>
-    </menu>
-  </menubar>
-</ui>
-"""
-
 class PythonConsolePlugin (GObject.Object, Peas.Activatable):
     __gtype_name__ = 'PythonConsolePlugin'
 
@@ -79,41 +65,20 @@ class PythonConsolePlugin (GObject.Object, Peas.Activatable):
     def do_activate (self):
         self.totem = self.object
 
-        data = dict ()
-        manager = self.totem.get_ui_manager ()
-
-        data['action_group'] = Gtk.ActionGroup (name = 'Python')
-
-        action = Gtk.Action (name = 'Python', label = 'Python',
-                             tooltip = _(u'Python Console Menu'),
-                             stock_id = None)
-        data['action_group'].add_action (action)
-
-        action = Gtk.Action (name = 'PythonConsole',
-                             label = _(u'_Python Console'),
-                             tooltip = _(u"Show Totem's Python console"),
-                             stock_id = 'gnome-mime-text-x-python')
+        action = Gio.SimpleAction.new ("python-console", None)
         action.connect ('activate', self._show_console)
-        data['action_group'].add_action (action)
+        self.totem.add_action (action)
+
+        menu = self.totem.get_menu_section ("python-console-placeholder")
+        menu.append (_('_Python Console'), "app.python-console")
 
-        action = Gtk.Action (name = 'PythonDebugger',
-                             label = _(u'Python Debugger'),
-                             tooltip = _(u"Enable remote Python debugging "\
-                                          "with rpdb2"),
-                             stock_id = None)
         if HAVE_RPDB2:
+            action = Gio.SimpleAction.new ("python-debugger", None)
             action.connect ('activate', self._enable_debugging)
-        else:
-            action.set_visible (False)
-        data['action_group'].add_action (action)
+            self.totem.add_action (action)
+            menu.append (_('Python Debugger'), "app.python-debugger")
 
-        manager.insert_action_group (data['action_group'], 0)
-        data['ui_id'] = manager.add_ui_from_string (UI_STR)
-        manager.ensure_update ()
-
-        self.totem.PythonConsolePluginInfo = data
-
-    def _show_console (self, _action):
+    def _show_console (self, parameter, _action): # pylint: disable-msg=W0613
         if not self.window:
             console = PythonConsole (namespace = {
                 '__builtins__' : __builtins__,
@@ -122,11 +87,11 @@ class PythonConsolePlugin (GObject.Object, Peas.Activatable):
             }, destroy_cb = self._destroy_console)
 
             console.set_size_request (600, 400) # pylint: disable-msg=E1101
-            console.eval ('print "%s" %% totem_object' % _(u"You can access "\
+            console.eval ('print("%s" %% totem_object)' % _("You can access "\
                 "the Totem.Object through \'totem_object\' :\\n%s"), False)
 
             self.window = Gtk.Window ()
-            self.window.set_title (_(u'Totem Python Console'))
+            self.window.set_title (_('Totem Python Console'))
             self.window.add (console)
             self.window.connect ('destroy', self._destroy_console)
             self.window.show_all ()
@@ -135,8 +100,8 @@ class PythonConsolePlugin (GObject.Object, Peas.Activatable):
             self.window.grab_focus ()
 
     @classmethod
-    def _enable_debugging (cls, _action):
-        msg = _(u"After you press OK, Totem will wait until you connect to it "\
+    def _enable_debugging (cls, param, _action): # pylint: disable-msg=W0613
+        msg = _("After you press OK, Totem will wait until you connect to it "\
                  "with winpdb or rpdb2. If you have not set a debugger "\
                  "password in DConf, it will use the default password "\
                  "('totem').")
@@ -153,19 +118,12 @@ class PythonConsolePlugin (GObject.Object, Peas.Activatable):
             GObject.idle_add (start_debugger, password)
         dialog.destroy ()
 
-    def _destroy_console (self, *_args):
+    def _destroy_console (self, *_args): # pylint: disable-msg=W0613
         self.window.destroy ()
         self.window = None
 
     def do_deactivate (self):
-        data = self.totem.PythonConsolePluginInfo
-
-        manager = self.totem.get_ui_manager ()
-        manager.remove_ui (data['ui_id'])
-        manager.remove_action_group (data['action_group'])
-        manager.ensure_update ()
-
-        self.totem.PythonConsolePluginInfo = None
+        self.totem.empty_menu_section ("python-console-placeholder")
 
         if self.window is not None:
             self.window.destroy ()
